@@ -2,13 +2,14 @@
 \donttest{
 # Run where Python available
 if (reticulate::py_module_available("numpy")) {
-
-raw_data <- data.table(a = sample(c("red","yellow","blue",NA),1000, replace = TRUE),
-                       b = 1:1000,
-                       c = sample(c("YES","NO",NA),1000,replace=TRUE),
-                       d = runif(1000,1,10),
-                       e = sample(c("YES","NO"), 1000, replace = TRUE),
-                       f = sample(c("male","female","trans","other",NA), 1000, replace = TRUE))
+set.seed(89)
+n_obs <- 10000
+raw_data <- data.table(a = sample(c("red","yellow","blue",NA),n_obs, replace = TRUE),
+                       b = 1:n_obs,
+                       c = sample(c("YES","NO",NA),n_obs,replace=TRUE),
+                       d = runif(n_obs,1,10),
+                       e = sample(c("YES","NO"), n_obs, replace = TRUE),
+                       f = sample(c("male","female","trans","other",NA), n_obs, replace = TRUE))
 
 # Names of bin./cat. variables
 test_bin <- c("c","e")
@@ -24,7 +25,7 @@ test_data <- convert(raw_data,
 test_imp <- train(test_data)
 
 # Generate datasets
-complete_datasets <- complete(test_imp, m = 5)
+complete_datasets <- complete(test_imp, m = 5, fast = FALSE)
 
 # Use Rubin's rules to combine m regression models
 midas_pool <- combine(formula = d~a+c+e+f,
